@@ -4,7 +4,6 @@ import os
 
 import gdown
 import numpy as np
-from hpman.m import _
 from sysflow.utils.common_utils.file_utils import dump, load, make_dir
 from tqdm import trange
 from neuralsampler.mcmc.langevin import langevin
@@ -60,7 +59,9 @@ def generate_traj(args, gen=False):
 
     else:
         URL = {
-            "mb": {2: "1Y52BXL-rbEFcjNTAHwIn7S6FNtYRyVXv"},
+            "mb": {2: "1Y52BXL-rbEFcjNTAHwIn7S6FNtYRyVXv",
+                   3: "1-UW5nRZcMTUx8yqkvr2KYZpERiVxmz-F",
+                   10: "1yvzrLXkbs_8DyTZRNnZDGcYnaSSk26FY"},
             "dw": {2: "1QGvp94Wtrg_HgwnFGnhyf1vYjB-Ctw6P",
                    3: "1-pVVd1KPUS84AvNKoQbp9Q1P3ZnmF0Yd",
                    10: "1bxrHyUHYAE4ILjWuJzbt5TGuMh3TwwMY"},
