@@ -85,41 +85,52 @@ def generate_init(args, gen=False):
             dump(my_dict, os.path.join("./dataset/init", fname))
 
 
-
-
     else: 
         # TO BE filled in
         URL = {
             'mb': 
             {
-                2: '1MCrVSUTFsHag3kxB50kLJHp1lUn89THj'
+                2: ['1MCrVSUTFsHag3kxB50kLJHp1lUn89THj', '1LuZI7Zd6HwP_bxZ-bj2bV2xNiuguQIjL', '1qDrihMonvG6Iy9aAC6tMjAsp1akPzE03']
             }, 
             'dw': {
                 2: ''
             }
         }
 
-        url = 'https://drive.google.com/uc?id={}'.format(URL[model][dim])
-        # create a folder and dump the data
-        make_dir("./dataset")
-        make_dir("./dataset/init")
-        fname = "{}_d{}.pkl".format(model, dim)
-        fname = os.path.join("./dataset/init", fname)
-        gdown.download(url, fname, quiet=False)
+        dim = 2 
+        
+        if isinstance(URL[model][dim], str): 
+            url = 'https://drive.google.com/uc?id={}'.format(URL[model][dim])
+            # create a folder and dump the data
+            make_dir("./dataset")
+            make_dir("./dataset/init")
+            fname = "{}_d{}.pkl".format(model, dim)
+            fname = os.path.join("./dataset/init", fname)
+            gdown.download(url, fname, quiet=False)
+        elif isinstance(URL[model][dim], list):
+            assert (len(URL[model][dim]) == 3)
+            for ur, subfix in zip(URL[model][dim], ['', '_2', '_3']):  
+                url = 'https://drive.google.com/uc?id={}'.format(ur)
+                # create a folder and dump the data
+                make_dir("./dataset")
+                make_dir("./dataset/init")
+                fname = "{}_d{}{}.pkl".format(model, dim, subfix)
+                fname = os.path.join("./dataset/init", fname)
+                gdown.download(url, fname, quiet=False)
 
 
 
-        URL = {
-            'mb': 
-            {
-                2: '1ZAGuUDK1uIbKXWi2N81MRJzs2YMZnRkL'
-            }, 
-            'dw': {
-                2: ''
-            }
-        }
+        # URL = {
+        #     'mb': 
+        #     {
+        #         2: '1ZAGuUDK1uIbKXWi2N81MRJzs2YMZnRkL'
+        #     }, 
+        #     'dw': {
+        #         2: ''
+        #     }
+        # }
 
-        url = 'https://drive.google.com/uc?id={}'.format(URL[model][dim])
-        fname = "{}_d{}_plot.pkl".format(model, dim)
-        fname = os.path.join("./dataset/init", fname)
-        gdown.download(url, fname, quiet=False)
\ No newline at end of file
+        # url = 'https://drive.google.com/uc?id={}'.format(URL[model][dim])
+        # fname = "{}_d{}_plot.pkl".format(model, dim)
+        # fname = os.path.join("./dataset/init", fname)
+        # gdown.download(url, fname, quiet=False)
\ No newline at end of file
