@@ -64,7 +64,10 @@ def generate_anim(args):
     sample_dict = load(fname)
 
     if 'GAN' in G_loss: 
-        fig, axes = plt.subplots(1, 3, figsize=(6.4 * 3, 4.8))
+        if model == 'mb': 
+            fig, axes = plt.subplots(3, 3, figsize=(6.4 * 3, 4.8))
+        else: 
+            fig, axes = plt.subplots(1, 3, figsize=(6.4 * 3, 4.8))
     else: 
         fig, axes = plt.subplots(1, 2, figsize=(6.4 * 2, 4.8))
 
@@ -79,22 +82,47 @@ def generate_anim(args):
         # placeholder here
         D_list = sample_dict["Z"]
 
-    for X, Y, Z, D in tzip(X_list, Y_list, Z_list, D_list):
-        ax = axes[0]
-        ax.contourf(X, Y, Z)
+    if model == 'mb': 
+        for XX, YY, ZZ, DD in tzip(X_list, Y_list, Z_list, D_list):
+            for i in range(3): 
+                X = XX[i]
+                Y = YY[i]
+                Z = ZZ[i]
+                D = DD[i]
 
-        ax = axes[1]
-        if model == 'mb': 
-            ax.contourf(X_ref, Y_ref, Z_ref)
-        elif model == 'dw': 
-            Z_ref = np.exp( - 0.045 * X ** 4 + X ** 2 - 0.5 * Y ** 2)
-            ax.contourf(X, Y, Z_ref)
+                ax = axes[i, 0]
+                ax.contourf(X, Y, Z)
 
-        if 'GAN' in G_loss: 
-            ax = axes[2]
-            ax.contourf(X, Y, D)
+                ax = axes[i, 1]
+                if model == 'mb': 
+                    ax.contourf(X_ref, Y_ref, Z_ref)
+                elif model == 'dw': 
+                    Z_ref = np.exp( - 0.045 * X ** 4 + X ** 2 - 0.5 * Y ** 2)
+                    ax.contourf(X, Y, Z_ref)
+
+                if 'GAN' in G_loss: 
+                    ax = axes[i, 2]
+                    ax.contourf(X, Y, D)
+                    
+            camera.snap()
+    else: 
+        for X, Y, Z, D in tzip(X_list, Y_list, Z_list, D_list):
+            ax = axes[0]
+            ax.contourf(X, Y, Z)
+
+            ax = axes[1]
+            if model == 'mb': 
+                ax.contourf(X_ref, Y_ref, Z_ref)
+            elif model == 'dw': 
+                Z_ref = np.exp( - 0.045 * X ** 4 + X ** 2 - 0.5 * Y ** 2)
+                ax.contourf(X, Y, Z_ref)
+
+            if 'GAN' in G_loss: 
+                ax = axes[2]
+                ax.contourf(X, Y, D)
+
+            camera.snap()
 
-        camera.snap()
     animation = camera.animate()
 
     fname = "{}_d{}.mp4".format(model, dim)
